/* game.c --- 
 * 
 * Filename: game.c
 * Author: Jules <archjules>
 * Created: Mon Apr 17 22:03:59 2017 (+0200)
 * Last-Updated: Sat Apr 22 23:07:28 2017 (+0200)
 *           By: Jules <archjules>
 */
#include <display.h>
#include <stdio.h>
#include <stdlib.h>
#include <utils.h>
#include <clock.h>
#include <game.h>

struct Game game_state;

/*
 * Cette fonction retourne le nom d'un joueur.
 */
char * get_name(int id) {
    char * names[] = {
	"Kropotkine",
	"Staline",
	"Keynes",
	"Mussolini"
    };
    
    return names[id];
}

/*
 * Cette fonction initialise game_state aux valeurs par défaut.
 */
void game_init(int player) {
    game_state.player = player;

    game_state.in_course[0] = 1;
    game_state.in_course[1] = 1;
    game_state.in_course[2] = 1;
    game_state.in_course[3] = 1;
    game_state.nb_course = 4;
    
    game_state.corruption[0] = 5;
    game_state.money[0] = 500;
    game_state.corruption[1] = 10;
    game_state.money[1] = 1000;
    game_state.corruption[2] = 20;
    game_state.money[2] = 2000;
    game_state.corruption[3] = 30;
    game_state.money[3] = 3000;
    
    game_state.religious[0] = 100;
    game_state.religious[1] = 50;
    game_state.religious[2] = 200;
    game_state.religious[3] = 650;

    game_state.scholars[0] = 550;
    game_state.scholars[1] = 100;
    game_state.scholars[2] = 300;
    game_state.scholars[3] = 50;

    game_state.farmers[0] = 300;
    game_state.farmers[1] = 300;
    game_state.farmers[2] = 200;
    game_state.farmers[3] = 200;

    game_state.employees[0] = 50;
    game_state.employees[1] = 550;
    game_state.employees[2] = 300;
    game_state.employees[3] = 100;

    // Percentage in the population
    int a[4], b = 0;
    for (int i = 0; i < 4; i++) {
	a[i] = rand() / 1000;
	b += a[i];
    }

    game_state.percentage[0] = (a[0] * 1000) / b;
    game_state.percentage[1] = (a[1] * 1000) / b;
    game_state.percentage[2] = (a[2] * 1000) / b;
    game_state.percentage[3] = (a[3] * 1000) / b;
}

/*
 * Cette fonction retourne le score d'un joueur
 */
int get_score(int player) {
    return (game_state.percentage[0] * game_state.religious[player])
	+  (game_state.percentage[1] * game_state.scholars[player])
	+  (game_state.percentage[2] * game_state.farmers[player])
	+  (game_state.percentage[3] * game_state.employees[player]);
}

/*
 * Cette fonction met à jour le HID, c'est à dire
 * la zone en haut de l'écran
 */
void update_hid() {
    char buffer[15];

    dclear_hid();
    dprint(0, 0, "%02d%%", game_state.corruption[game_state.player]);
    
    snprintf(buffer, 15, "%dk", game_state.money[game_state.player]);
    right(0, buffer);

    snprintf(buffer, 15, "%d%%", get_score(game_state.player) / 10000);
    center(0, buffer);
    
    dupdate();
}

/*
 * Cette fonction est appelée quand un joueur perd.
 */
void lose(int player) {
    char buffer[25];
    game_state.in_course[player] = 0;
    game_state.nb_course -= 1;

    dclear_main();
    
    if (player == game_state.player) {
	center(20, "Vous avez perdu...");
    } else {
	snprintf(buffer, 25, "%s a perdu...", get_name(player));
	center(20, buffer);
    }

    dupdate();
    sleep_ms(2000);
}

void check_defeat(int player) {
    if ((game_state.religious[player] <= 0) ||
	(game_state.scholars[player]  <= 0) ||
	(game_state.farmers[player]   <= 0) ||
	(game_state.employees[player] <= 0)) {
	lose(player);
    }
}

/*
 * Cette fonction vérifie si un joeur a perdu.
 */
void earn_money(int player, int choix) {
    switch(choix) {
    case 0:
	game_state.money[player] +=
	    (50 + game_state.corruption[player] * 2) * 10;
	game_state.corruption[player] += 2;
	break;
    case 1:
	game_state.money[player] +=
	    (25 + game_state.corruption[player] * 4) * 10;
	game_state.corruption[player] += 5;
	break;
    case 2:
	game_state.money[player] += 1000;
	game_state.corruption[player] += 7;
	break;
    }
}

/*
 * Cette fonction fait prendre une mesure à un joueur pour
 * un électorat précis.
 */
void mesure(int * elec, int player) {
    int modif = rand() % 50;

    for (int i = 0; i < 4; i++) {
	if (i == player) {
	    elec[i] += modif * (game_state.nb_course - 1);
	} else if (game_state.in_course[i]) {
	    elec[i] -= modif;
	    check_defeat(i);
	}
    }
}

/*
 * Cette fonction vérifie si une affaire sort sur un joueur,
 * en fonction de sa corruption.
 */
void affaires() {
    for (int i = 0; i < 4; i++) {
	if (game_state.in_course[i]
	    && ((rand() % 100) < game_state.corruption[i])) {
	    dclear_main();
	    center(20, "Une affaire est sortie sur");
	    center(26, get_name(i));
	    dupdate();

	    // On retire entre 0 et 2% dans chaque électorat
	    game_state.religious[i] -= rand() % 20;
	    game_state.scholars[i]  -= rand() % 20;
	    game_state.farmers[i]   -= rand() % 20;
	    game_state.employees[i] -= rand() % 20;
	    check_defeat(i);
	    
	    sleep_ms(1000);
	}
    }
}

/*
 * La fonction principale du jeu, elle fait jouer tour à tour
 * tout les joueurs.
 */
void game_main(int player) {
    dclear();
    // Init game_state
    game_init(player);
    
    update_hid();

    while(game_state.in_course[game_state.player]) {
	for (int i = 0; i < 4; i++) {
	    if (game_state.in_course[i]
		&& game_state.in_course[game_state.player]) {
		if (i == game_state.player)
		    main_menu();
		else
		    ia(i);
	    }
	}

	if (game_state.in_course[game_state.player]) affaires();
    }
}
