/* menu.c --- 
 * 
 * Filename: menu.c
 * Author: Jules <archjules>
 * Created: Wed Apr 19 17:26:06 2017 (+0200)
 * Last-Updated: Sat Apr 22 23:10:22 2017 (+0200)
 *           By: Jules <archjules>
 */
#include <stdio.h>
#include <display.h>
#include <keyboard.h>
#include <utils.h>
#include <game.h>

/*
 * Menu du jeu permettant de 
 * promettre diverses mesures.
 */
int mesures_menu() {
    int choix = 0, key;
    const int position_fleches[] = {27, 20, 29, 22};
    
    do {
	dclear_main();

	center(20, "Mesure religieuse");
	center(26, "Mesure universitaire");
	center(32, "Mesure agricole");
	center(38, "Mesure \x13""conomique");

	dprint(position_fleches[choix], 20 + choix * 6, "\x02");

	update_hid();
	dupdate();
	key = handle_input(&choix, 4);
    } while((key != 2) && (key != 1));

    if (key == 1) {
	if (game_state.money[game_state.player] >= 250) {
	    game_state.money[game_state.player] -= 250;
	    
	    switch(choix) {
	    case 0: mesure(game_state.religious, game_state.player); break;
	    case 1: mesure(game_state.scholars,  game_state.player); break;
	    case 2: mesure(game_state.farmers,   game_state.player); break;
	    case 3: mesure(game_state.employees, game_state.player); break;
	    }

	    return 1;
	} else {
	    dclear_main();
	    center(20, "Vous n'avez pas assez");
	    center(26, "d'argent pour prendre");
	    center(32, "une mesure.");

	    dupdate();
	    wait_input();
	    return 0;
	}
    }
    
    return 0;
}

/*
 * Ici on rend l'argent.
 */
int rendre_argent() {
    int choix = 1; int key;
    
    do {
	dclear_main();

	center(15, "Voulez-vous vraiment");
	center(21, "rendre l'argent ?");

	center(31, "Oui");
	center(37, "Non");

	dprint((choix) ? 53 : 54, 31 + choix * 6, "\x02");
	dupdate();
	key = handle_input(&choix, 2);
    } while(key == 0);

    if ((key == 1) && (!choix)) {
	dclear();
	center(20, "Vous avez rendu l'argent.");
	center(32, "Vous avez perdu, mais");
	center(38, "l'argent a \x13t\x13 rendu.");
	dupdate();

	game_state.in_course[game_state.player] = 0;
	wait_input();
	
	return 1;
    }

    return 0;
}

/*
 * Menu permettant de gagner de l'argent
 * en augmentant la corruption
 */
int argent_menu() {
    int choix = 0, key;
    const int position_fleches[] = {20, 24, 7, 28};
    
    do {
	dclear_main();

	center(20, "Demander \x10 un ami");
	center(26, "Utiliser Bygmalion");
	center(32, "Organiser un emploi fictif");
	center(38, "Rendre l'argent");

	dprint(position_fleches[choix], 20 + choix * 6, "\x02");

	update_hid();
	dupdate();
	key = handle_input(&choix, 4);
    } while((key != 2) && (key != 1));

    if (key == 1) {
	switch(choix) {
	case 0:
	case 1:
	case 2:
	    earn_money(game_state.player, choix);
	    return 1;
	case 3:
	    return rendre_argent();
	}
    }

    return 0;
}

/*
 * Menu qui affiche la popularité de chaque candidat
 */
int sondages() {
    char buffer[25];
    int choix = game_state.player;
    int finished = 0, prog = 0; key_t key;

    do {
	dclear_main();
	
	center(10, (char *)get_name(choix));
       
	snprintf(buffer, 25, "Religieux : %d.%d%%",
		 game_state.religious[choix] / 10,
		 game_state.religious[choix] % 10);
	center(22, buffer);
	
	snprintf(buffer, 25, "Universitaires : %d.%d%%",
		 game_state.scholars[choix] / 10,
		 game_state.scholars[choix] % 10);
	center(28, buffer);
	
	snprintf(buffer, 25, "Agriculteurs : %d.%d%%",
		 game_state.farmers[choix] / 10,
		 game_state.farmers[choix] % 10);
	center(34, buffer);
	
	snprintf(buffer, 25, "Salari\x13s : %d.%d%%",
		 game_state.employees[choix] / 10,
		 game_state.employees[choix] % 10);
	center(40, buffer);

	dprint(0, 30, "\x01");
	dprint(124, 30, "\x02");
	dupdate();
	
	key = getkey_opt(getkey_none, 0);

	// Easter egg ici, fermez vos yeux
	switch(prog) {
	case 0: if (key == KEY_UP) prog++; break;
	case 1: if (key == KEY_UP) prog++; else prog = 0; break;
	case 2: if (key == KEY_DOWN) prog++; else prog = 0; break;
	case 3: if (key == KEY_DOWN) prog++; else prog = 0; break;
	case 4: if (key == KEY_LEFT) prog++; else prog = 0; break;
	case 5: if (key == KEY_RIGHT) prog++; else prog = 0; break;
	case 6: if (key == KEY_LEFT) prog++; else prog = 0; break;
	case 7: if (key == KEY_RIGHT) prog++; else prog = 0; break;
	case 8: if (key == KEY_XOT) prog++; else prog = 0; break;
	case 9:
	    if (key == KEY_LOG) {
		dclear_main();
		center(20, "Vous avez trouv\x13 un");
		center(26, "easter egg !");
		center(38, "Voici un cookie.");

		game_state.religious[game_state.player] = 420;
		game_state.scholars[game_state.player]  = 420;
		game_state.farmers[game_state.player]   = 420;
		game_state.employees[game_state.player] = 420;

		dupdate();
		wait_input();
	    }
	}
	
	switch(key) {
	case KEY_LEFT:
	    do {
		choix--;
		if (choix < 0) choix += 4;
	    } while(!game_state.in_course[choix]);
	    break;
	case KEY_RIGHT:
	    do {
		choix = (choix + 1) % 4;
	    } while(!game_state.in_course[choix]);
	    break;
	case KEY_EXIT:
	    handle_exit();
	default:
	    break;
	}
    } while(key != KEY_ALPHA);

    return 0;
}

/*
 * Menu principal pour jouer son tour.
 */
void main_menu() {
    int choix = 0;
    int key, finished = 0;
    const int position_fleches[] = {42, 46, 41};
    
    do {
	dclear_main();

	center(20, "Proposer");
	center(26, "Argent");
	center(32, "Sondages");

	dprint(position_fleches[choix], 20 + choix * 6, "\x02");

	dupdate();

	key = handle_input(&choix, 3);
	if (key == 1) {
	    switch(choix) {
	    case 0:
		finished = mesures_menu();
		break;
	    case 1:
		finished = argent_menu();
		break;
	    case 2:
		finished = sondages();
		break;
	    }
	}
    } while(!finished);
    
    update_hid();
}
