/* utils.c --- 
 * 
 * Filename: utils.c
 * Author: Jules <archjules>
 * Created: Mon Apr 17 14:47:47 2017 (+0200)
 * Last-Updated: Sat Apr 22 23:13:22 2017 (+0200)
 *           By: Jules <archjules>
 */
#include <stdlib.h>
#include <display.h>
#include <keyboard.h>
#include <utils.h>

/*
 * Mettre du texte au centre de l'écran.
 */
void center(int y, char * s) {
    int x = (128 - text_length(s)) / 2;
    dtext(x, y, s);
}

/*
 * Mettre du texte à droite de l'écran
 */
void right(int y, char * s) {
    int x = 128 - text_length(s);
    dtext(x, y, s);
}

/*
 * Dialogue de confirmation pour quitter le jeu.
 */ 
void handle_exit() {
    key_t key;
    int choix = 1;
    
    do {
	dclear();
	center(5, "Voulez-vous vraiment");
	center(11, "quitter le jeu ?");

	center(31, "Oui");
	center(37, "Non");

	dprint((choix) ? 53 : 54, 31 + choix * 6, "\x02");
	dupdate();
	
	key = getkey_opt(getkey_none, 0);
	switch (key) {
	case KEY_ALPHA:
	    return;
	case KEY_UP:
	case KEY_DOWN:
	    choix = !choix;
	    break;
	case KEY_EXIT:
	    exit(0);
	}
    } while((key != KEY_EXE) && (key != KEY_SHIFT));

    if (!choix) exit(0);
}

/*
 * Gérer l'entrée clavier pour les menus verticaux
 */
int handle_input(int * choix, int n) {
    key_t key = getkey_opt(getkey_none, 0);
    
    switch(key) {
    case KEY_UP:
	(*choix)--;
	if ((*choix) < 0) (*choix) += n;
	break;
    case KEY_DOWN:
	(*choix) = (*choix + 1) % n;
	break;
    case KEY_EXE:
    case KEY_SHIFT:
	return 1;
    case KEY_ALPHA:
	return 2;
    case KEY_EXIT:
	handle_exit();
    default:
	break;
    }

    return 0;
}

/*
 * Attends une entrée clavier.
 */
void wait_input() {
    key_t key = getkey_opt(getkey_none, 0);

    if (key == KEY_EXIT) handle_exit();
}
